==> nextcloud-20.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/nl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Show something" : "Toon iets",
    "Customize" : "Aanpassen",
    "Edit widgets" : "Bewerken widgets",
    "Get more widgets from the app store" : "Krijg meer widgets vanuit de appstore",
    "Change background image" : "Wijzigen achtergrondafbeelding",
    "Weather service" : "Weerberichten",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Voor je privacy worden de weergegevens namens jou opgevraagd door je Nextcloud-server, zodat de weerservice geen persoonlijke informatie ontvangt.",
    "Weather data from Met.no" : "Weerbericht via Met.no",
    "geocoding with Nominatim" : "geocoding met Nominatim",
    "elevation data from OpenTopoData" : "hellingsdata via OpenTopoData",
    "Weather" : "Weer",
    "Status" : "Status",
    "Good evening, {name}" : "Goedenavond, {name}",
    "Good evening" : "Goedenavond",
    "Good afternoon, {name}" : "Goedemiddag, {name}",
    "Good afternoon" : "Goedemiddag",
    "Good morning, {name}" : "Goedemorgen, {name}",
    "Good morning" : "Goedemorgen",
    "Good night, {name}" : "Goedenacht, {name}",
    "Good night" : "Goedenacht",
    "Pick from files" : "Kies uit bestanden",
    "Default images" : "Standaardafbeeldingen",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/nl.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Dashboard",
    "Dashboard app" : "Dashboard app",
    "Show something" : "Toon iets",
    "Customize" : "Aanpassen",
    "Edit widgets" : "Bewerken widgets",
    "Get more widgets from the app store" : "Krijg meer widgets vanuit de appstore",
    "Change background image" : "Wijzigen achtergrondafbeelding",
    "Weather service" : "Weerberichten",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Voor je privacy worden de weergegevens namens jou opgevraagd door je Nextcloud-server, zodat de weerservice geen persoonlijke informatie ontvangt.",
    "Weather data from Met.no" : "Weerbericht via Met.no",
    "geocoding with Nominatim" : "geocoding met Nominatim",
    "elevation data from OpenTopoData" : "hellingsdata via OpenTopoData",
    "Weather" : "Weer",
    "Status" : "Status",
    "Good morning" : "Goedemorgen",
    "Good morning, {name}" : "Goedemorgen, {name}",
    "Good afternoon" : "Goedemiddag",
    "Good afternoon, {name}" : "Goedemiddag, {name}",
    "Good evening" : "Goedenavond",
    "Good evening, {name}" : "Goedenavond, {name}",
    "Hello" : "Hallo",
    "Hello, {name}" : "Hallo, {name}",
    "Pick from Files" : "Kies uit Bestanden",
    "Default images" : "Standaardafbeeldingen",
    "Plain background" : "Kale achtergrond",
    "Insert from {productName}" : "Invoegen vanuit {productName}",
    "Good night, {name}" : "Goedenacht, {name}",
    "Good night" : "Goedenacht",
    "Pick from files" : "Kies uit bestanden"
},
"nplurals=2; plural=(n != 1);");
